package com.yidian.bcommon.sdk

/**
 * author: yinjiacheng
 * date: 7/28/21 11:22 AM
 * description: 加解密服务接口定义
 */
interface IEncryptService {
  /**
   * RSA私钥签名
   * @param src 需要签名的字符串
   * @return 签名结果
   */
  fun sign(src: String): String

  /**
   * RSA公钥验签
   * @param src 原始串
   * @param sign 签名串
   * @return 是否通过
   */
  fun verifySign(src: String, sign: String): Boolean

  /**
   * RSA公钥加密
   * @param src 需要加密的字符串
   * @return 加密结果
   */
  fun rsaEncrypt(src: String): String

  /**
   * RSA私钥解密
   * @param src 加密串
   */
  fun rsaDecrypt(src: String): String

  /**
   * AES加密
   * @param src 需要加密的字符串
   * @return 加密结果
   */
  fun aesEncrypt(src: String): String

  /**
   * AES解密
   * @param src 加密串
   */
  fun aesDecrypt(src: String): String
}
